@@ -246,6 +246,7 @@ class Art(GObject.GObject):
         remote_art = RemoteArt()
         remote_art.connect('retrieved', self._remote_art_retrieved)
         remote_art.connect('unavailable', self._remote_art_unavailable)
+        remote_art.connect('no-remote-sources', self._remote_art_no_sources)
         remote_art.query(self._media)
 
     @log
@@ -260,6 +261,10 @@ class Art(GObject.GObject):
         self._add_to_blacklist()
         self._no_art_available()
 
+    @log
+    def _remote_art_no_sources(self, klass):
+        self._no_art_available()
+
     @log
     def _no_art_available(self):
         self._surface = DefaultIcon().get(
@@ -610,7 +615,8 @@ class RemoteArt(GObject.GObject):
 
     __gsignals__ = {
         'retrieved': (GObject.SignalFlags.RUN_FIRST, None, ()),
-        'unavailable': (GObject.SignalFlags.RUN_FIRST, None, ())
+        'unavailable': (GObject.SignalFlags.RUN_FIRST, None, ()),
+        'no-remote-sources': (GObject.SignalFlags.RUN_FIRST, None, ())
     }
 
     def __repr__(self):
@@ -631,10 +637,20 @@ class RemoteArt(GObject.GObject):
         """
         self._album = utils.get_album_title(media)
         self._artist = utils.get_artist_name(media)
+        self._media = media
 
-        # FIXME: It seems this Grilo query does not always return,
-        # especially on queries with little info.
-        grilo.get_album_art_for_item(media, self._remote_album_art)
+        if not grilo.props.cover_sources:
+            self.emit('no-remote-sources')
+            grilo.connect(
+                'notify::cover-sources', self._on_grilo_cover_sources_changed)
+        else:
+            # FIXME: It seems this Grilo query does not always return,
+            # especially on queries with little info.
+            grilo.get_album_art_for_item(media, self._remote_album_art)
+
+    def _on_grilo_cover_sources_changed(self, klass, data):
+        if grilo.props.cover_sources:
+            grilo.get_album_art_for_item(self._media, self._remote_album_art)
 
     @log
     def _delete_callback(self, src, result, data):
