@@ -28,6 +28,7 @@ from gi.repository import GdkPixbuf, GLib, GObject, Gtk
 from gnomemusic import log
 from gnomemusic.albumartcache import Art, ArtImage
 from gnomemusic.grilo import grilo
+from gnomemusic.player import PlayerPlaylist
 from gnomemusic.widgets.disclistboxwidget import DiscBox
 from gnomemusic.widgets.disclistboxwidget import DiscListBox  # noqa: F401
 from gnomemusic.widgets.songwidget import SongWidget
@@ -127,11 +128,14 @@ class AlbumWidget(Gtk.EventBox):
         art = ArtImage(Art.Size.LARGE, item)
         art.image = self._cover
 
-        GLib.idle_add(grilo.populate_album_songs, item, self.add_item)
-
         self._album = utils.get_album_title(item)
-        self._artist_label.props.label = utils.get_artist_name(item)
+        artist = utils.get_artist_name(item)
+
         self._title_label.props.label = self._album
+        self._title_label.props.tooltip_text = self._album
+
+        self._artist_label.props.label = artist
+        self._artist_label.props.tooltip_text = artist
 
         year = utils.get_media_year(item)
         if not year:
@@ -142,6 +146,17 @@ class AlbumWidget(Gtk.EventBox):
 
         self._player.connect('song-changed', self._update_model)
 
+        # If an album is playing, restore it.
+        if self._player.playing_playlist(
+                PlayerPlaylist.Type.ALBUM, self._album):
+            length = len(self._player.get_songs())
+            for i, song in enumerate(self._player.get_songs()):
+                self.add_item(None, None, song[0], length - (i + 1))
+            self.add_item(None, None, None, 0)
+            self._update_model(self._player)
+        else:
+            GLib.idle_add(grilo.populate_album_songs, item, self.add_item)
+
     @log
     def _set_composer_label(self, item):
         composer = item.get_composer()
@@ -186,9 +201,9 @@ class AlbumWidget(Gtk.EventBox):
             song_widget.props.selected = not song_widget.props.selected
             return
 
-        self._player.stop()
         self._player.set_playlist(
-            'Album', self._album, song_widget.model, song_widget.itr)
+            PlayerPlaylist.Type.ALBUM, self._album, song_widget.model,
+            song_widget.itr)
         self._player.play()
         return True
 
@@ -196,60 +211,55 @@ class AlbumWidget(Gtk.EventBox):
     def add_item(self, source, prefs, song, remaining, data=None):
         """Add a song to the item to album list.
 
-        :param source: The grilo source
-        :param prefs:
-        :param song: The grilo media object
-        :param remaining: Remaining number of items to add
+        If no song is remaining create DiscBox and display the widget.
+        :param GrlTrackerSource source: The grilo source
+        :param prefs: not used
+        :param GrlMedia song: The grilo media object
+        :param int remaining: Remaining number of items to add
         :param data: User data
         """
         if song:
             self._songs.append(song)
-
-            self._duration = self._duration + song.get_duration()
+            self._duration += song.get_duration()
             return
 
-        discs = {}
-        for song in self._songs:
-            disc_nr = song.get_album_disc_number()
-            if disc_nr not in discs.keys():
-                discs[disc_nr] = [song]
-            else:
-                discs[disc_nr].append(song)
-        for disc_nr in discs:
-            disc = self._create_disc_box(disc_nr, discs[disc_nr])
-            self._disc_listbox.add(disc)
-            if len(discs) == 1:
-                disc.props.show_disc_label = False
-
         if remaining == 0:
-            self._set_duration_label()
+            discs = {}
+            for song in self._songs:
+                disc_nr = song.get_album_disc_number()
+                if disc_nr not in discs.keys():
+                    discs[disc_nr] = [song]
+                else:
+                    discs[disc_nr].append(song)
 
+            for disc_nr in discs:
+                disc = self._create_disc_box(disc_nr, discs[disc_nr])
+                if len(discs) == 1:
+                    disc.props.show_disc_label = False
+                self._disc_listbox.add(disc)
+
+            self._set_duration_label()
             self.show_all()
 
     @log
-    def _update_model(self, player, playlist, current_iter):
-        """Player changed callback.
+    def _update_model(self, player, position=None):
+        """Updates model when the song changes
 
-        :param player: The player object
-        :param playlist: The current playlist
-        :param current_iter: The current iter of the playlist model
+        :param Player player: The main player object
+        :param int position: current song position
         """
-        if not player.playing_playlist('Album', self._album):
+        if not player.playing_playlist(PlayerPlaylist.Type.ALBUM, self._album):
             return True
 
-        current_song = playlist[current_iter][player.Field.SONG]
-
+        current_song = player.props.current_song
         self._duration = 0
-
         song_passed = False
-        _iter = playlist.get_iter_first()
 
-        while _iter:
-            song = playlist[_iter][player.Field.SONG]
+        for song in self._songs:
             song_widget = song.song_widget
             self._duration += song.get_duration()
 
-            if (song == current_song):
+            if (song.get_id() == current_song.get_id()):
                 song_widget.props.state = SongWidget.State.PLAYING
                 song_passed = True
             elif (song_passed):
@@ -258,8 +268,6 @@ class AlbumWidget(Gtk.EventBox):
             else:
                 song_widget.props.state = SongWidget.State.PLAYED
 
-            _iter = playlist.iter_next(_iter)
-
         self._set_duration_label()
 
         return True
